import os
import shutil, subprocess

def find_resolve_executable():
    exec_path = [os.environ['PROGRAMFILES'], os.environ['PROGRAMFILES']]

    for data_path in exec_path:
        resolve_exe = os.path.join(data_path, "Blackmagic Design", "DaVinci Resolve", "Resolve.exe")
        if os.path.exists(resolve_exe):
            return resolve_exe

    # resolve_exe = shutil.which("python")  # Available with Python > 3.3

    raise RuntimeError("Cannot find Resolve data directory")

def find_resolve_data_directory():
    data_paths = [os.environ['PROGRAMDATA'], os.environ['APPDATA'], os.environ['LOCALAPPDATA']]

    for data_path in data_paths:
        script_api = os.path.join(data_path, "Blackmagic Design", "DaVinci Resolve", "Support", "Developer", "Scripting")
        if os.path.exists(script_api):
            return os.path.join(data_path, "Blackmagic Design", "DaVinci Resolve")

    raise RuntimeError("Cannot find Resolve data directory")


def main():
    import resolve_startup

    resolve_data_dir = find_resolve_data_directory()
    resolve_exe = find_resolve_executable()
    environ = os.environ.copy()

    environ['RESOLVE_SCRIPT_API'] = os.path.join(resolve_data_dir, "Support", "Developer", "Scripting")
    environ['RESOLVE_SCRIPT_LIB'] = os.path.join(os.path.dirname(resolve_exe), "fusionscript.dll")

    PATHS = environ['PATH'].split(';')
    PATHS = [path for path in PATHS if "Python" not in path] + \
            [environ['RESOLVE_SCRIPT_LIB']]

    PYTHONPATHS = environ.get('PYTHONPATH', '').split(';')
    PYTHONPATHS = [path for path in PYTHONPATHS if "Python" not in path] \
                  + [
                      os.path.join(environ['RESOLVE_SCRIPT_API'], "Modules"),
                      os.path.dirname(resolve_startup.__file__)
                  ]

    environ['PATH'] = ';'.join(PATHS)
    environ['PYTHONPATH'] = ';'.join(PYTHONPATHS)
    startup_content = \
    """
    fu:Execute([[!Py: import %(module)s
%(module)s.run()
    ]])
    
    """ % {"module": resolve_startup.__name__}
    with open(os.path.join(os.path.join(resolve_data_dir, "Fusion", "Scripts"), "resolve_startup.scriptlib"), 'w') as fs:
        fs.write(startup_content)

    subprocess.check_call([resolve_exe], env=environ)

if __name__ == '__main__':
    main()